@@ -633,9 +633,8 @@ _ufc_setup_salt_r(s, __data)
 }
 
 void
-_ufc_mk_keytab_r(key, __data)
-     const char *key;
-     struct crypt_data * __restrict __data;
+_ufc_mk_keytab_r (const char *key, 
+		  struct crypt_data * __restrict __data)
 {
   ufc_long v1, v2, *k1;
   int i;
@@ -885,7 +884,7 @@ __xsetkey_r (__const char *__key,
 {
   int i,j;
   unsigned char c;
-  unsigned char ktab[8];
+  char ktab[8];
 
   _ufc_setup_salt_r("..", __data); /* be sure we're initialized */
 
